/*
 * hash.h - Bob Jenkin's one-at-a-time hash
 *
 * Copyright (c) Chris Putnam 2020-2021
 *
 * Source code released under the GPL version 2
 */
#ifndef HASH_H
#define HASH_H

unsigned int calculate_hash_char( const char *key, unsigned int HASH_SIZE );

#endif
